@@ -296,7 +296,7 @@ def parse_arguments():
     )
     args = parser.parse_args()
     for t in args.track:
-        if not any((t.endswith(ext) for ext in ('.bw', '.bdg', '.bed'))):
+        if not any((t.endswith(ext) for ext in ('.bw', '.bdg', '.bed', 'bdg.gz', 'bed.gz'))):
             raise RuntimeError(
                 'track file extensions must be one of .bw, .bdg, or .bed')
     if args.genes in set(GENOME_TO_GENES.keys()):
